import os
import pathlib

import pytest


@pytest.fixture
def test_host_cert_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIIC+zCCAeMCFCTQmEgIErlEb0dap4sFeCkmQyYbMA0GCSqGSIb3DQEBCwUAMDkx
CzAJBgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxGTAXBgNVBAMMEFRlc3QgQ2Vy
dGlmaWNhdGUwIBcNMjEwNTIwMTgxMzA1WhgPMjEyMTA0MjYxODEzMDVaMDkxCzAJ
BgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxGTAXBgNVBAMMEFRlc3QgQ2VydGlm
aWNhdGUwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQC7lEBKkJu9XWt6
1wLinWPnKZydd/sz1pfzROa8IGtKJTB8AKEIZEJ68rz8s03gTPHlpIHxjOfmf+cR
4FqhA2iRTwenEFXc+hb3m0bBKg/w1DPtgFflJJXHSCH8jG/YiKEXWPyLImmy36/A
97t0v2JUtbwCA1lFCoKjEbwbUT7znvRe0gJUyy8EiTPJlvTe6jiohNzQdV4B4odx
ZCv36L8vHbnKUjvzWwLGXPgqKCheM/X1Trrl8UtmTf/z99URS5++ALhRnaz5thHL
SGtu84k1Re1RCMknz6QeqF68xiEKsJ+s2f6XKOGy3vLmVslXqJKgfYyVi1S15loJ
pAVH7+r1AgMBAAEwDQYJKoZIhvcNAQELBQADggEBAKT7o2pPlqA5RduFq9Gh+k2q
uz5UeHjC2ot8g+KWEDT4WtEs0dCHhj4kp1Wp7vZ5dRXc2GMqHUbmbMdt4jGkoAY2
Ra33pzyS3vZJbfGjnwxbc6GgAlhKPbEzI1D9gb244oPr9UdB9seCqVYoTNjYXfp0
KIEA7J0GX/xxo2ZXM+Ol9isI1IhUIjnymof4j0TNptHQTk2k5v0T+DXpeA2ORWLM
hd0BJgkH4hHdAs+wv7oEJMd0h2dt+lHgOuFpMpJkgTqcS27HcydoXTq8p/ooDJgy
FChTOV1iGYEywbsNByrC3pMXn/D4nC9O5a02OfTmOIQqBCcAzaGs6f8h08r+R4s=
-----END CERTIFICATE-----"""


@pytest.fixture
def test_host_cert_subject() -> str:
    return "/C=US/O=Globus/CN=Test Certificate"


@pytest.fixture
def test_host_cert_file(
    tmp_path: pathlib.Path, test_host_cert_data: str
) -> "os.PathLike[str]":
    name = tmp_path / "hostcert.pem"
    with open(name, "w") as f:
        print(test_host_cert_data, file=f)

    return name


@pytest.fixture
def test_user_cert_data() -> str:
    return """\
-----BEGIN CERTIFICATE-----
MIIC7TCCAdUCFBjzJt97v3gx689FHhibsLdN/52PMA0GCSqGSIb3DQEBCwUAMDIx
CzAJBgNVBAYTAlVTMQ8wDQYDVQQKDAZHbG9idXMxEjAQBgNVBAMMCVVzZXIgQ2Vy
dDAgFw0yMTA1MjExNDExMTdaGA8yMTIxMDQyNzE0MTExN1owMjELMAkGA1UEBhMC
VVMxDzANBgNVBAoMBkdsb2J1czESMBAGA1UEAwwJVXNlciBDZXJ0MIIBIjANBgkq
hkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAu5RASpCbvV1retcC4p1j5ymcnXf7M9aX
80TmvCBrSiUwfAChCGRCevK8/LNN4Ezx5aSB8Yzn5n/nEeBaoQNokU8HpxBV3PoW
95tGwSoP8NQz7YBX5SSVx0gh/Ixv2IihF1j8iyJpst+vwPe7dL9iVLW8AgNZRQqC
oxG8G1E+8570XtICVMsvBIkzyZb03uo4qITc0HVeAeKHcWQr9+i/Lx25ylI781sC
xlz4KigoXjP19U665fFLZk3/8/fVEUufvgC4UZ2s+bYRy0hrbvOJNUXtUQjJJ8+k
HqhevMYhCrCfrNn+lyjhst7y5lbJV6iSoH2MlYtUteZaCaQFR+/q9QIDAQABMA0G
CSqGSIb3DQEBCwUAA4IBAQBTzN50sGa1PRJRFb0lq1OoZqB0ccfm0BHgOu4M8yEC
jKF5L1tRSrWu3S2BCeORabRjDtCE5cLOAlEw6RvSJUztNtWCqAtVPY0ful+44oYp
aXHm+nrZX01iFbACktm696301Q0IG9T4QFfoCOYDwubtTzr9Mk+QNGfFSMRqzW6C
xG7ozC2r9ennvsddYUKKgb+FkxGjfTecyi5PNwiAunCv4k0JDviP3kkminZYh9FL
06cLUx5eCu8EZexmHjvZCdoxroy3JAWu0GzuahTKLSb0erQuQBizgeZas4CHyT3v
GNWI4Knwzg54yulydyp8/oI7xDfku+LVjvv2C0CBwvHg
-----END CERTIFICATE-----"""


@pytest.fixture
def test_user_cert_subject() -> str:
    return "/C=US/O=Globus/CN=User Cert"


@pytest.fixture
def test_user_subject_hash() -> str:
    return "35a688bd"


@pytest.fixture
def test_private_key_data() -> str:
    return """\
-----BEGIN RSA PRIVATE KEY-----
MIIEowIBAAKCAQEA0ykWCGVwXczyyhejBfZaB7uLEQj1oznUV/KhCd8MeFLM1sAb
xVJAY0yHKUncKXf/su27cTwgG3N4qsRzuT5qcbusiM1nh3mRiUyzAdXaxy/GbZW1
Gbhw2+/F27Yr/R2GMKMGP8DgM92HtKVYcLT71zerBZA86s1UTWEew0pKUpn0rCTM
oGgaijuBKvViIBqrlfCPsWg6te68nVt6Lk/nSPlzlXhRuXtJTdhaDoZO15BroEDs
xRi9Reo9I8pm3FKEoKaLBKIlwRqfedEJGkCEK12Iu6aAVc7N3zEU7lFyCrtedDI2
zlWpwA9znHSkpFHb9CxDggDqEtLSVZemEqdZCwIDAQABAoIBAGl9CQjAxFXX4SKc
lFCSNX/PbTXhZ/VXGoGlMFYiG7SwiKxv5G+7G3d/77XstBPzYsYchZuYEeIk2Y9V
/Qn56GtQ+myNUL8ZOF+C9ZphH56Ke3Kba5Gh1p/JNOsCIw+cBEGf76tBy7+dWAIi
5//GKlnl8YYh/IzAbvEJJ7kgD+kbH55sjtk/RdIj+EEA09ooj29kfVQEqXD0NaDS
JPy+NMB+PJxZQMIsmuH7OCAnAcVkIlqdlwc7AfNx6He+UYypkrJLyNijf4Kmklxl
yGh23WyFIxooVdppg+wiTyFwVrZSggdZQFhKvNn7b4wH4i+0EeS/fWzvq7v3Eccs
GqGUFKECgYEA98Jan4FI4ilq7zk1T1lqEowEHpbJzG7gJ9D3d7kdS6xEgA06FhW+
6TSvWAJ+Z8IwoHTYrAle+CZLpkE96l9avToL3oa3ME6+J9vtLqn8izZS+k9NXYol
0wF4STiX/gEHhBUXV4t275W6I82mvPXFP24+3FxaZXItkpRE11gPYScCgYEA2i8Y
+9C51BALUgHRbNxshvYQP37AWsePY8+dK1hd6hh6DHCFUPmMa35698MJq5+SNrVu
jtMq033bfGFyrEF0g/gditW1eXLwbfXWzfkLWMs8Sg7NzEs+JtQKNv2yQil4XKfk
O+wNkiAigaLFaWO/vINKDxGH7JgdxqJYRFDzb30CgYBRFUIjQWRg370nXUmdFl4o
g7o1aJPSW9bwMOtMO0DjKxWf8rQ31hYMrDlWTDqiKmNPn+3pH4f9HktTtbZVpa9E
jmKkCOKa5KpG0SrmQqtrw/OUB7ACFNwcGjcLf4H+lsem6mAhPntGHXI1lXAkFyre
f24DIBZVbPCNMAj3kNI3sQKBgB0rktGH9HBPvNO3/oHpbnEU0NNMZPc+GwOjLEYx
SE0V/KtRF+Hdm1J71IDviIlzih7aXu+ld+JSv1d/x88T6ToDoB+BtwOHxHFPHurm
0weKFINqO0WHAcY7Lypu/LgvxzHMGI2SX7YbqcFfO7l9ZpMTkoE1PND6/XAjIF3x
3LoZAoGBAJ7U0QEv6PHg2lHiu7SypwzUoDLNd04YrA2PwmoGje8v2EDD3+LJ07WW
V9H5a6jUn1ijCHZ4JxaJL1g66ZHU9eYXtyQS0k8GfIfUccVQ6NNgsdLEEn9toSux
gl2AZ43o5dOXAZiFzjssyxK3KXu8b3t98XB0ZMvYj896sJvz7Jn3
-----END RSA PRIVATE KEY-----"""


@pytest.fixture
def test_private_key_file(
    tmp_path: pathlib.Path, test_private_key_data: str
) -> "os.PathLike[str]":
    name = tmp_path / "private_key.pem"

    with open(name, "w") as f:
        print(test_private_key_data, file=f)

    return name
